:root{
--theme-back: black;
--theme-fore: cyan;
--theme-border: red;

}
#non-navigation{
display:flex;
flex-direction:column;
align-items:center;
justify-content:center;
}
*{
font-size:16vw;
padding:7%;
border-radius:32vw;
}
body{
display:flex;
flex-direction:row;
background:black;
color:var(--theme-fore);
text-shadow:2px 2px 4px cyan;
}

.navigation-panel{
display:flex;
flex-direction: column;
gap:3vw;
padding:10%;
margin:5px;
border:2px solid cyan;
}
.hide-element{
display:none;
/*width:0%;
overflow:scroll;*/
}
#btns{
display:flex;
position:sticky;
top:0%;
}
#btns>*{
background:black;
border:2px solid var(--theme-fore);
color:cyan;
}
#nano{
background:linear-gradient(cyan,greenyellow);
border:5px solid var(--theme-fore);
margin:20px;


}
iframe{
width:90%;
height:40%;
}
#terminal{
background:transparent;
color:cyan;
border:2px solid cyan;
}
#commands,#commands:focus{
background:transparent;
border:none;
padding:0px;
color:cyan;
}