
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>File Manager</title>
<link rel="stylesheet" href="{{url_for('static',filename='css/style.css')}}">
</link>
</head>
<body>
    <!-- JAI JAI SIYA RAM!  -->
<div id="navigation-panel" data-name='navigation' data-type='nav' class="hide-element">
{{nav | safe}}</div>
<div id="non-navigation">
<div id="btns">
<button id="nav-btn">Toggle Navigation</button>
<button id="save-btn">Save</button>
<button id="run-btn">Run</button></div>
<form method="POST">
<h1 id="cwd" >{{path}}/<span id="total-path"></span></h1>
<!--<input id="path" name="path" type="url" />
<div><select id="selected" name="selected">
</select>
</div>-->
<textarea id="nano" name="nano" rows="40" cols="40">
</textarea>
<!--<textarea id="terminal" name="terminal" rows="40" cols="40">
 </textarea>-->
<div id="terminal">
<div id="history"></div>
<form>
<input id="commands" name="terminal" type="text" />
</form>
</div>
<iframe src="https://comdotharman0.github.io/"></iframe>
</form></div><script>

window.MyConstants={
"url":"{{url_for('file_manager_response')}}",
"method":"POST"
}
</script>
<script 
src="{{url_for('static',filename='js/script.js')}}"
 defer >
</script>
</body>
</html>

