<html>

<head>

<title>JS Window</title>


</head>

<body>


<script defer>
function CreateElement(tagName,className,content,parent){
let elem=document.createElement(tagName);
elem.classList.add(className);
elem.innerHTML=content;
parent.appendChild(elem);
return elem;
 }
let i=0;
function ExpandAll(ob){
i+=1;
//alert(i);
try{
let elem="";
if(i>2500){
return elem;
}
for(let i in ob){

if(typeof(ob[i])==typeof({})){
elem+="<h1><details><summary> "+i+"</summary> === ";
elem+=ExpandAll(ob[i])+" </details></h1>"; 
}else{
elem+="<h3> "+i+" === "+ob[i]+" h3</h3>"
}
}
return elem;
}catch(err){
alert(err);
}
}
function main(){
try{
alert(document.body.parentNode.innerHTML)
//alert(dir(geolocation.clearWatch()));
CreateElement("div","window",ExpandAll(document.body.parentNode.childNodes),
document.body);
CreateElement("div","window",Object.keys(window),
document.body);

}catch(err){
alert(err+" ++ "+typeof(err));
}
}

main();

</script>
</body>
</html>
